@@ -1,5 +1,5 @@
 CaseData[64] = {
-    "title": "Case 123 - 24 yr old male with penetrating eye injury", 
+    "title": "Case 123 - 24 yr old male with penetrating eye injury and full stomach", 
     "badDrugs": ["Dantrolene"], 
     "coMin": 1.2, 
     "debriefMsg": "RSI with open eye injury based on case 23", 
@@ -14,7 +14,7 @@ CaseData[64] = {
     "leanBodyMass": 76, 
     "learningObj": "", 
     "possiblePoints": 1200, 
-    "preopMsg": "\n24 yr old male with penetrating eye injury and full stomach\n\nHistory of Present Illness\nThe patient sustained a penetrating eye injury one hour ago.\n\nPast Medical History\nIllnesses - None\nSurgeries - None\nMedications - None\nHabits - Denies cigarettes, alcohol or other drugs.\nNo known drug allergies.\n\nFamily History\nNo family history of anesthetic problems.\n\nPhysical Exam\nThin, anxious male in pain\nWeight: 76 Kg\nHR 108,  BP 142/86,  RR 20\nAirway - normal\nLungs - clear \nHeart - normal\nNumerous scars\n\nLabs\nHematocrit 40%\nLytes, Glucose, Bun, Cr - normal\n\nNPO Status\nLast ate a large meal 2 hours ago.  \n\nPatient and Surgeon Requests\nThe procedure requires general anesthesia. \nThe surgeon states the procedure will take one hour.\n\n", 
+    "preopMsg": "\n24 yr old male with penetrating eye injury and full stomach\n\nHistory of Present Illness\nThe patient sustained a penetrating eye injury one hour ago.\n\nPast Medical History\nIllnesses: None\nSurgeries: None\nMedications: None\nHabits: Denies cigarettes, alcohol or other drugs.\nNo known drug allergies.\n\nFamily History\nNo family history of anesthetic problems.\n\nPhysical Exam\nThin, anxious male in pain\nWeight : 76 Kg           HR : 108         BP : 142/86\tRR : 20\nAirway : normal\nLungs : clear \nHeart : normal\nNumerous scars\n\nLabs\nHematocrit: 40%\nLytes, Glucose, Bun, Cr : normal\n\nNPO Status\nLast ate a large meal 2 hours ago.  \n\nPatient and Surgeon Requests\nThe procedure requires general anesthesia. \nThe surgeon states the procedure will take one hour.\n\n", 
     "volAnDsp": 80, 
     "states": [
         {
@@ -48,7 +48,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong and regular.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 0, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Awake, alert, and anxiously awaiting induction.", 
             "rhythm": "Sinus1", 
@@ -100,7 +100,7 @@ CaseData[64] = {
                             "value": 0.6
                         }
                     ], 
-                    "points": -500
+                    "points": -400
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -185,7 +185,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 0, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Awake but paralyzed.", 
             "rhythm": "Sinus1", 
@@ -273,7 +273,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong and regular.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 0, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Preoxygenated and anxiously awaiting induction.", 
             "rhythm": "Sinus1", 
@@ -312,7 +312,7 @@ CaseData[64] = {
                             "value": true
                         }
                     ], 
-                    "points": -500
+                    "points": -300
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -398,7 +398,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong and regular.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 0, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Cricoid pressure is being applied to this anxious patient.", 
             "rhythm": "Sinus1", 
@@ -419,7 +419,7 @@ CaseData[64] = {
             "trans": [
                 {
                     "nextState": "READY", 
-                    "comment": "You preoxygenated after applying cricoid pressure.", 
+                    "comment": "You preoxygenated after applying cricoid pressure. (Lost points)", 
                     "conditions": [
                         {
                             "op": "GT", 
@@ -438,7 +438,7 @@ CaseData[64] = {
                             "value": true
                         }
                     ], 
-                    "points": -500
+                    "points": -300
                 }, 
                 {
                     "nextState": "COUGH5", 
@@ -449,7 +449,7 @@ CaseData[64] = {
                             "value": true
                         }
                     ], 
-                    "points": -500
+                    "points": -300
                 }, 
                 {
                     "nextState": "HURT5", 
@@ -495,7 +495,7 @@ CaseData[64] = {
         }, 
         {
             "name": "READY", 
-            "whatNextMsg": "Administer induction dose of propofol.", 
+            "whatNextMsg": "Administer defasciculating dose of competitive neuromuscular blocker then administer an induction dose of propofol.", 
  			"airwayStr": "nl",
             "aspirateCvpMsg": "10 mL blood was aspirated from the CVP catheter.", 
             "baseAbpD": 92, 
@@ -524,7 +524,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong and regular.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 0, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Preoxygenated and anxiously awaiting induction.", 
             "rhythm": "Sinus1", 
@@ -656,7 +656,7 @@ CaseData[64] = {
                             "value": 200
                         }
                     ], 
-                    "points": -100
+                    "points": -50
                 }, 
                 {
                     "nextState": "DEEP", 
@@ -745,7 +745,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is strong and fast.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 0, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Upset and coughing.", 
             "rhythm": "Sinus1", 
@@ -861,7 +861,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is bounding.", 
             "pupilsMsg": "The pupils are equal, round, and react to light.", 
-            "rateEbl": 8, 
+            "rateEbl": 20, 
             "rateUo": 1.5, 
             "recordMsg": "Screaming and writhing in pain.", 
             "rhythm": "Sinus1", 
@@ -949,7 +949,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Asleep.", 
             "rhythm": "Sinus1", 
@@ -1011,7 +1011,7 @@ CaseData[64] = {
                             "value": 150
                         }
                     ], 
-                    "points": -100
+                    "points": -50
                 }, 
                 {
                     "nextState": "ASLEEPPARA", 
@@ -1083,7 +1083,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Asleep and paralyzed.", 
             "rhythm": "Sinus1", 
@@ -1169,7 +1169,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Deeply anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1303,7 +1303,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Deeply anesthetized and paralyzed.", 
             "rhythm": "Sinus1", 
@@ -1380,7 +1380,7 @@ CaseData[64] = {
             "heartSoundsMsg": "Regular rate and rhythm, without murmurs.", 
             "hiCo2ProdFlag": false, 
             "laryTubeSuccess": 1, 
-            "lidReflexMsg": "The lid reflex is minimal.", 
+            "lidReflexMsg": "The lid reflex is slowed.", 
             "lmaSuccessFlag": true, 
             "mentalStatusMsg": "The patient is unresponsive.", 
             "papD": 12, 
@@ -1389,7 +1389,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are small.", 
-            "rateEbl": 0, 
+            "rateEbl": 8, 
             "rateUo": 1.5, 
             "recordMsg": "Lightly anesthetized with intravenous agents.", 
             "rhythm": "Sinus1", 
@@ -1417,7 +1417,7 @@ CaseData[64] = {
                             "value": true
                         }
                     ], 
-                    "points": -300
+                    "points": -100
                 }, 
                 {
                     "nextState": "GA2", 
@@ -1476,7 +1476,7 @@ CaseData[64] = {
             "papW": 12, 
             "pulseMsg": "The pulse is present.", 
             "pupilsMsg": "The pupils are pinpoint.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Adequately anesthetized.", 
             "rhythm": "Sinus1", 
@@ -1802,7 +1802,7 @@ CaseData[64] = {
             "papW": 8, 
             "pulseMsg": "The pulse is weak and slow.", 
             "pupilsMsg": "The pupils are small.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Hypoxic and bradycardic.", 
             "rhythm": "Sinus1", 
@@ -1866,7 +1866,7 @@ CaseData[64] = {
             "papW": 8, 
             "pulseMsg": "The pulse is weak and very slow.", 
             "pupilsMsg": "The pupils are large.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Hypoxic and severely bradycardic.", 
             "rhythm": "Sinus1", 
@@ -1931,7 +1931,7 @@ CaseData[64] = {
             "papW": 18, 
             "pulseMsg": "The pulse is absent.", 
             "pupilsMsg": "The pupils are large.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "Hypoxic and asystolic.", 
             "rhythm": "Asystole1", 
@@ -1996,7 +1996,7 @@ CaseData[64] = {
             "papW": 18, 
             "pulseMsg": "The pulse is absent.", 
             "pupilsMsg": "The pupils are fixed and dilated.", 
-            "rateEbl": 0, 
+            "rateEbl": 5, 
             "rateUo": 1.5, 
             "recordMsg": "The patient cannot be resuscitated.", 
             "rhythm": "Asystole1", 
