@@ -5,6 +5,7 @@
 // require_once $_SERVER['DOCUMENT_ROOT'] . '/.sys/wp-load.php'; // for auth using wp as headless
 // require_once 'config.php';
 require_once 'includes/include_all.inc.php';
+require_once 'includes/debug_mode.php';
 
 // Enhanced cache invalidation protocol for immediate state refresh
 if (isset($_SESSION['clear_cache']) && $_SESSION['clear_cache'] === true) {
@@ -223,7 +224,7 @@ $expiration = $userDetailsPro['expiration'] ?? '';
 	<script src="app/scripts/prototype.js" type="application/javascript"></script>		
 	<!-- script src="app/scripts/iscroll-lite.js" type="application/javascript" defer></script   was -->    
 	<script src="app/scripts/AboutAnesthSim7.js?v=<?php echo date('YmdHis'); ?>" type="application/javascript" defer></script>
-	<script src="app/scripts/AnesthCode.js?v=4" type="application/javascript" defer></script>
+	<script src="app/scripts/AnesthCode.js?v=<?php echo date('YmdHis'); ?>" type="application/javascript" defer></script>
 	<script src="app/scripts/Default.js?v=<?php echo date('YmdHis'); ?>" type="application/javascript" defer></script>
 	<script src="app/scripts/DrugInfo.js?v=<?php echo date('YmdHis'); ?>" type="application/javascript" defer></script>
 	<script src="app/scripts/IvAdmin.js?v=<?php echo date('YmdHis'); ?>" type="application/javascript" defer></script>
@@ -312,6 +313,7 @@ $expiration = $userDetailsPro['expiration'] ?? '';
 	<script src="app/cases_updated/Anesth6Case137.js?v=<?php echo date('YmdHis'); ?>" type="text/javascript" defer></script>
 	<script src="app/cases_updated/Anesth6Case138.js?v=<?php echo date('YmdHis'); ?>" type="text/javascript" defer></script>
 	<script src="app/cases_updated/Anesth6Case139.js?v=<?php echo date('YmdHis'); ?>" type="text/javascript" defer></script>
+	<script src="/app/scripts/CaseSaveDebug.js?v=<?php echo date('YmdHis'); ?>"></script>
 	
 	<?php /* was hemoWaveform files */ ?>
 	<script src="app/hemoWaveforms/afib6_160.js" type="text/javascript" defer></script>
@@ -620,6 +622,14 @@ $expiration = $userDetailsPro['expiration'] ?? '';
 						<span class="label">Session Termination:</span>
 						<span class="session-text">On</span>
 					</li>
+					<li class="settings-toggles debug-logging-toggle" id="debug-logging-toggle">
+						<i class="fas fa-bug"></i>
+						<span class="label">Debug Logs:</span>
+						<div class="toggle-options">
+							<button class="toggle-option <?php echo isDebugModeEnabled() ? 'active' : ''; ?>" data-value="on">On</button>
+							<button class="toggle-option <?php echo !isDebugModeEnabled() ? 'active' : ''; ?>" data-value="off">Off</button>
+						</div>
+					</li>
 				<?php } ?>
 			</ul>
 		</div>
