@@ -471,4 +471,9 @@ $expiration = $userDetailsPro['expiration'] ?? '';
 		<a href="#" class="breadcrumbs-item" id="settings-breadcrumb">Settings</a>
 		<a href="#" class="breadcrumbs-item" id="dynamic-breadcrumb"></a>
 		<a href="#" class="breadcrumbs-item" id="case-breadcrumb" style="display: none;"></a>
-	</div>
\ No newline at end of file
+	</div>
+
+	<?php
+	require_once 'includes/save_message.php';
+	displayFlashMessage();
+	?>
\ No newline at end of file
