@@ -2,11 +2,11 @@
 	  window.performance.mark('scriptStart');
 	  document.addEventListener('DOMContentLoaded', () => {
 		window.performance.mark('DOMContentLoaded');
-		// console.log('DOMContentLoaded time:', performance.now());
+		console.log('DOMContentLoaded time:', performance.now());
 	  });
 	  window.addEventListener('load', () => {
 		window.performance.mark('windowLoaded');
-		// console.log('Window loaded time:', performance.now());
+	//	console.log('Window loaded time:', performance.now());
 		const scriptStartToNow = performance.measure('scriptStartToNow', 'scriptStart');
-		// console.log('Time since script start:', scriptStartToNow.duration);
+	//	console.log('Time since script start:', scriptStartToNow.duration);
 	  });
\ No newline at end of file
