@@ -996,7 +996,6 @@ document.querySelectorAll('.copy-icon').forEach(icon => {
 });
 
 /* hide copy icon when no overflow */
-
 window.addEventListener('load', () => {
     document.querySelectorAll('.copy-icon').forEach(icon => {
         const textEl = icon.previousElementSibling.querySelector('.inner-text');
@@ -1006,4 +1005,62 @@ window.addEventListener('load', () => {
             icon.style.removeProperty('display');
         }
     });
-}); 
\ No newline at end of file
+}); 
+
+
+// Debug Logging Toggle
+const debugLoggingToggle = document.getElementById('debug-logging-toggle');
+if (debugLoggingToggle) {
+    const debugButtons = debugLoggingToggle.querySelectorAll('.toggle-option');
+    debugButtons.forEach(button => {
+        button.addEventListener('click', function() {
+            const mode = this.getAttribute('data-value');
+            
+            fetch('/api/toggle_debug_mode.php', {
+                method: 'POST',
+                headers: {'Content-Type': 'application/x-www-form-urlencoded'},
+                body: 'mode=' + mode
+            })
+            .then(response => response.json())
+            .then(data => {
+                if (data.success) {
+                    debugButtons.forEach(btn => btn.classList.remove('active'));
+                    this.classList.add('active');
+                    console.log('Debug mode set to:', mode);
+                } else {
+                    console.error('Failed to toggle debug mode:', data.message);
+                }
+            })
+            .catch(error => console.error('Error:', error));
+        });
+    });
+}
+
+
+// ================================================================
+// SESSION KEEPALIVE FOR LONG-RUNNING SIMULATIONS
+// ================================================================
+
+let sessionKeepaliveInterval = null;
+
+function startSessionKeepalive() {
+    if (sessionKeepaliveInterval) {
+        console.log("Session keepalive already running");
+        return;
+    }
+    console.log("Starting session keepalive (pings every 5 minutes)");
+    sessionKeepaliveInterval = setInterval(() => {
+        fetch('/api/keepalive.php', {method: 'POST'})
+            .then(r => r.json())
+            .then(d => console.log('Session keepalive ping:', d))
+            .catch(e => console.error('Keepalive error:', e));
+    }, 300000);
+}
+
+function stopSessionKeepalive() {
+    if (sessionKeepaliveInterval) {
+        console.log("Stopping session keepalive");
+        clearInterval(sessionKeepaliveInterval);
+        sessionKeepaliveInterval = null;
+    }
+}
